import { Component, OnInit, Input, OnDestroy  } from "@angular/core";

import { IManagedObject, IMeasurement, IEvent, IAlarm, FetchClient } from "@c8y/client";
import { ThingsCloudDataSupplier } from "./tc-data-supplier";

@Component({
  selector: "table-template",
  templateUrl: "./table-template.component.html",
  styleUrls: ["./table-template.component.css"]
})
export class TableTemplate implements OnInit, OnDestroy {
  private thingsCloudDataSupplier: ThingsCloudDataSupplier;
  @Input() config: any;
  dataSource: any[];
  devices: IManagedObject[];
  measurements: IMeasurement[];
  events: IEvent[];
  alarms: IAlarm[]; 

  constructor(private fetchClient: FetchClient) {
    this.thingsCloudDataSupplier = new ThingsCloudDataSupplier(fetchClient);
  }

  ngOnInit(): void {
    (async () => {
      const data = await this.getData(this.config);
      this.dataSource = this.prepareDataSource(data);
    })();
  }

  /**
   * テーブルに表示するデータソースを準備します。
   * 
   * dataSourceは以下のような形式でサイズが device.length の配列が格納されます。
   * 各要素は単一の device に関する情報です。
   * つまり、measurement, event, alarm は、その device を source とする値が格納
   * されています。
   * 
   * [{
   *    device: {},
   *    measurement: {},
   *    event: {},
   *    alarm: {}
   *  },
   *  {
   *    device: {},
   *    measurement: {},
   *    event: {},
   *    alarm: {}
   *  },
   *  ...]
   * 
   * @param   data configで指定したデバイス/アセットの各種データ（device, measurement, event, alarm） 
   * @returns      テーブルに表示するための dataSource配列
   */  
    prepareDataSource(data: any): any[] {
      const dataSource = [];
      data.devices.forEach((device: any) => {
        dataSource.push({ 
          device: device,
          measurement: data.measurements.find(measurement => measurement.source.id === device.id),
          event: data.events.find(event => event.source.id === device.id),
          alarm: data.alarms.find(alarm => alarm.source.id === device.id)
        })
      });
      return dataSource;
    }

  /**
     * テーブルに表示するデータを取得する
     * 
     * @param config component config
     * 
     * @returns devices, measurements, alarms, events それぞれ配列で解決する Promise
     * {
     *    devices: [],
     *    measurements: [],
     *    events: [],
     *    alarms: []
     * }
     */
  async getData(config: any) : Promise<any> {
    const deviceId = config.device.id;
    const devices = await this.thingsCloudDataSupplier.getDevicesArray(deviceId);

    const dateTo = new Date().toISOString();
    const measurementFilter: any = {
      dateTo: dateTo,
      pageSize: 1,
      revert: true,
      flatten: false
    };
    if ( (!!config.fragmentType) && (!!config.fragmentSeries) ) {
      measurementFilter.valueFragmentType = config.fragmentType;
      measurementFilter.valueFragmentSeries = config.fragmentSeries;
    }

    const measurements = await this.thingsCloudDataSupplier.getMeasurementsArray(deviceId, measurementFilter);

    const alarmFilter: any = {
      dateTo: dateTo,
      // status: 'ACTIVE',
      pageSize: 1,
      // revert: false,
      flatten: false
    };
    if (config.alarmType) {
      alarmFilter.type = config.alarmType;
    }
    const alarms = await this.thingsCloudDataSupplier.getAlarmsArray(deviceId, alarmFilter);

    const eventFilter: any = {
      dateTo: dateTo,
      pageSize: 1,
      // revert: false,
      flatten: false
    };
    if (config.eventType) {
      eventFilter.type = config.eventType;
    }
    const events = await this.thingsCloudDataSupplier.getEventsArray(deviceId, eventFilter);

    return { devices, measurements, alarms, events };
  }

  /**
   * リアルタイム通知を受け取り、表のデータを更新します。
   * 
   * @param deviceId デバイスID
  */
   getRealtimeData(deviceId: string) {
    this.thingsCloudDataSupplier.getRealtimeMeasurement(deviceId)
      .subscribe((notifiedData: IMeasurement) => {
        this.updateDataSource('measurement', notifiedData);
        console.log(notifiedData);
      });

    this.thingsCloudDataSupplier.getRealtimeEvent(deviceId)
      .subscribe((notifiedData: IEvent) => {
        this.updateDataSource('event', notifiedData);
        console.log(notifiedData);
      });

      this.thingsCloudDataSupplier.getRealtimeAlarm(deviceId)
      .subscribe((notifiedData: IAlarm) => {
        this.updateDataSource('alarm', notifiedData);
        console.log(notifiedData);
      });

    this.thingsCloudDataSupplier.getRealtimeManagedObject(deviceId)
      .subscribe((notifiedData: IManagedObject) => {
        this.updateDataSource('device', notifiedData);
        console.log(notifiedData);
      });

  }

  updateDataSource(notifiedDataType: string, notifiedData: any): void{
    this.dataSource.forEach((dataRow) => {
      // 通知されたデータの source を確認し、該当の source の表データを更新
      if (notifiedDataType === 'device') { 
        // MO の通知データには source.id は存在しない
        if (dataRow.device.id === notifiedData.id) 
          dataRow[`${notifiedDataType}`] = notifiedData;
      } else {
        if (dataRow.device.id === notifiedData.source.id)
          dataRow[`${notifiedDataType}`] = notifiedData;
      }
    });
  }

  ngOnDestroy() {
    this.thingsCloudDataSupplier.unsubscribeRealtime();
  }
}
