import { IAlarm, IEvent, IMeasurement, IResultList, FetchClient, Realtime } from "@c8y/client";
export declare class ThingsCloudClient {
    private fetchClient;
    private measurementService;
    private alarmService;
    private eventService;
    private inventoryService;
    private realtime;
    /**
     * Things Cloudのデータを取得する
     * @class
     * @param {FetchClient} deviceId deviceId or groupId
     *
     *
     */
    constructor(fetchClient: FetchClient);
    /**
     * Things Cloud に接続し、Alarm 一覧を取得する
     *
     * @param {object} param
     *
     * @returns Promise<IResultList<IAlarm>>
     *
     * @example
     * ```typescript
     *
     *     const alarmsFilter = {
     *        deviceId: "123456",
     *        filter: {
     *          pageSize: 10,
     *          type: "c8y_UnavailabilityAlarm"
     *        }
     *     };
     *
     *    (async () => {
     *       const alarms = await thingsCloudClient.getAlarms(alarmsFilter);
     *    })();
     * ```
     */
    getAlarms(param: {
        deviceId: string;
        filter?: any;
    }): Promise<IResultList<IAlarm>>;
    /**
     * Things Cloud に接続し、Event 一覧を取得する
     *
     * @param {object} param
     *
     * @returns Promise<IResultList<IEvent>>
     *
     * @example
     * ```typescript
     *
     *     const eventsFilter = {
     *        deviceId: "123456",
     *        filter: {
     *          pageSize: 10,
     *          type: "c8y_LocationUpdate"
     *        }
     *     };
     *
     *    (async () => {
     *       const events = await thingsCloudClient.getEvents(eventsFilter);
     *    })();
     * ```
     */
    getEvents(param: {
        deviceId: string;
        filter?: any;
    }): Promise<IResultList<IEvent>>;
    /**
     * Things Cloud に接続し、Measurement 一覧を取得する
     *
     * @param {object} param
     *
     * @returns Promise<IResultList<IMeasurement>>
     *
     * @example
     * ```typescript
     *
     *     const measurementsFilter = {
     *        deviceId: "123456",
     *        filter: {
     *          pageSize: 10,
     *          valueFragmentType: "c8y_Temperature"
     *        }
     *     };
     *
     *    (async () => {
     *       const measurements = await thingsCloudClient.getMeasurements(measurementsFilter);
     *    })();
     * ```
     */
    getMeasurements(param: {
        deviceId: string;
        filter?: any;
    }): Promise<IResultList<IMeasurement>>;
    /**
     * MO ID に対し、サブアセット（ManagedObject の ID）を取得する。
     * ID がデバイスの場合、単独のデバイスが設定され、アセットの場合、再帰的に
     * 子アセットのデバイスが設定される。
     *
     * @param {string} moId MO ID
     *
     * @returns Promise デバイスIDの配列
     *
     * @example
     * ```typescript
     *
     *     const moId = "123456";
     *
     *    (async () => {
     *       const moIds = await thingsCloudClient.getSubAssets(moId);
     *    })();
     * ```
     */
    getSubAssets(moId: string): Promise<string[]>;
    /**
     * MO ID に対し、サブアセット（ManagedObject）を取得する。
     * ID がデバイスの場合、単独のデバイスが設定され、アセットの場合、再帰的に
     * 子アセットのデバイスが設定される。
     *
     * @param {string} moId MO ID
     *
     * @returns Promise デバイス ManagedObject の配列
     *
     * @example
     * ```typescript
     *
     *     const moId = "123456";
     *
     *    (async () => {
     *       const mos = await thingsCloudClient.getSubAssetMOs(moId);
     *    })();
     * ```
     */
    getSubAssetMOs(moId: string): Promise<any[]>;
    /**
     * リアルタイムにイベント等を取得するための Realtime オブジェクトを取得する
     *
     * @returns Realtime のインスタンス
     */
    getRealtime(): Realtime;
    /**
     * リアルタイム通知のチャネル監視を解除する
     *
     * @param subscription チャネル監視中のサブスクリプション
     */
    unsubscribeRealtime(subscription: any): void;
    /**
     * デバイスかグループを判断し、デバイスの場合はdevicesへpush、
     * グループの場合は再帰的に関数を呼び出す。
     *
     * @param {string} moId moId
     * @param {IManagedObject} devices デバイス情報のリスト
     *
     * @returns Promise<void>
     */
    private getSubAssetMOsImpl;
}
