import { IAlarm, IEvent, IMeasurement, IManagedObject, FetchClient } from "@c8y/client";
import { Subject } from 'rxjs';
export declare class ThingsCloudDataSupplier {
    private thingsCloudClient;
    private realtimeSubscription?;
    /**
     * ThingsCloudDataSupplierクラスのコンストラクタです。
     * 各メソッドでThingsCloudの対象テナントからデータを取得し、そのデータをフラット化して返却します。
     *
     * @class
     *
     * @param {baseUrl} baseUrl 情報を取得するテナントのURL
     * @param {user} user 情報を取得するための認証情報(ユーザ名)
     * @param {password} password 情報を取得するための認証情報(パスワード)
     *
     * @desc
     * *フラット化について*
     * このクラスでは、各メソッドで結果がフラット化され返却されます。例えば、データを取得した結果が
     * ```json
     * [
     *   {
     *     "c8y_Temperature": {
     *       "T": {
     *         "value": 18.0,
     *         "unit": "C"
     *       }
     *     }
     *   },
     *   :
     * ]
     * ```
     * のような JSON 構造だった場合、
     * ```json
     * [
     *   {
     *     "c8y_Temperature_T_value": 18.0,
     *     "c8y_Temperature_T_unit": "C"
     *   },
     *   :
     * ]
     * ```
     * のような形式の変換がなされます。
     * このようなデータ形式の変換操作をフラット化と呼びます。
     */
    constructor(fetchClient: FetchClient);
    /**
     * deviceId, measurementsFilterで指定されたデバイスのMeasurement情報を
     * 取得し、フラット化された(階層的なオブジェクト構造があった場合、ルートに設定した)
     * オブジェクトの配列として返却します。
     *
     * @param {string} deviceId deviceId or groupId (groupId を指定した場合、再帰的に子のデバイスが検索され、対象となります。)
     * @param {object} measurementsFilter Measurement のフィルタ条件を指定する情報
     *
     * @returns Measurement配列で解決する Promise
     * @example
     * ```typescript
     * async () => {
     *   :
     *   // thingsCloudDataSupplier にインスタンスを格納
     *   :
     *   const measurements = await thingsCloudDataSupplier.getMeasurementsArray('123456', {
     *     type: 'c8y_TemperatureMeasurement',
     *     dateFrom: '2022-02-01T00:00:00.000+09:00',
     *     dateTo: '2022-02-28T23:59:59.999+09:00'
     *   });
     * }
     * ```
     */
    getMeasurementsArray(deviceId: string, measurementsFilter: any): Promise<any[]>;
    /**
     * deviceId, alarmsFilterで指定されたデバイスのAlarm情報を
     * 取得し、フラット化された(階層的なオブジェクト構造があった場合、ルートに設定した)
     * オブジェクトの配列として返却します。
     *
     * @param {string} deviceId deviceId or groupId (groupId を指定した場合、再帰的に子のデバイスが検索され、対象となります。)
     * @param {object} alarmsFilter Alarm のフィルタ条件を指定する情報
     *
     * @returns Alarm配列で解決する Promise
     * @example
     * ```typescript
     * async () => {
     *   :
     *   // thingsCloudDataSupplier にインスタンスを格納
     *   :
     *   const alarms = await thingsCloudDataSupplier.getAlarmsArray('123456', {
     *     type: 'c8y_UnavailabilityAlarm',
     *     dateFrom: '2022-02-01T00:00:00.000+09:00',
     *     dateTo: '2022-02-28T23:59:59.999+09:00',
     *     status: 'CLEARED'
     *   });
     * }
     * ```
     */
    getAlarmsArray(deviceId: string, alarmsFilter: any): Promise<any[]>;
    /**
     * deviceId, eventsFilterで指定されたデバイスのEvent情報を
     * 取得し、フラット化された(階層的なオブジェクト構造があった場合、ルートに設定した)
     * オブジェクトの配列として返却します。
     *
     * @param {string} deviceId deviceId or groupId (groupId を指定した場合、再帰的に子のデバイスが検索され、対象となります。)
     * @param {object} eventsFilter Event のフィルタ条件を指定する情報
     *
     * @returns Event配列で解決する Promise
     * @example
     * ```typescript
     * async () => {
     *   :
     *   // thingsCloudDataSupplier にインスタンスを格納
     *   :
     *   const events = await thingsCloudDataSupplier.getEventsArray('123456', {
     *     type: 'c8y_UpdateEvent',
     *     dateFrom: '2022-02-01T00:00:00.000+09:00',
     *     dateTo: '2022-02-28T23:59:59.999+09:00'
     *   });
     * }
     * ```
     */
    getEventsArray(deviceId: string, eventsFilter: any): Promise<any[]>;
    /**
     * deviceIdで指定されたデバイスのMOリストをオブジェクトの配列として返却します
     *
     * @param {string} deviceId deviceId or groupId (groupId を指定した場合、再帰的に子のデバイスが検索され、対象となります。)
     *
     * @returns IManagedObject配列で解決する Promise
     * @example
     * ```typescript
     *
     * ```
     */
    getDevicesArray(deviceId: string): Promise<any[]>;
    /**
     * 対象のオブジェクトを監視し、メジャーメントのリアルタイム通知を受け取ります
     *
     * @param {string} target 監視対象オブジェクト deviceId or '*' (テナント内全てのデバイスが対象)
     *
     * @returns リアルタイム通知で受け取ったメジャーメント
     * @example
     * ```typescript
     *    thingsCloudDataSupplier.getRealtimeMeasurement('12345')
     *      .subscribe(notifiedData => {
                updateData();
     *      })
     * ```
     */
    getRealtimeMeasurement(target: string): Subject<IMeasurement>;
    /**
     * 対象のオブジェクトを監視し、アラームのリアルタイム通知を受け取ります
     *
     * @param {string} target 監視対象オブジェクト deviceId or '*' (テナント内全てのデバイスが対象)
     *
     * @returns リアルタイム通知で受け取ったアラーム
     * @example
     * ```typescript
     *    thingsCloudDataSupplier.getRealtimeAlarm('12345')
     *      .subscribe(notifiedData => {
     *         updateData();
     *       })
     *  ```
     */
    getRealtimeAlarm(target: string): Subject<IAlarm>;
    /**
     * 対象のオブジェクトを監視し、イベントのリアルタイム通知を受け取ります
     *
     * @param {string} target 監視対象オブジェクト deviceId or '*' (テナント内全てのデバイスが対象)
     *
     * @returns リアルタイム通知で受け取ったイベント
     * @example
     * ```typescript
     *    thingsCloudDataSupplier.getRealtimeEvent('12345')
     *      .subscribe(notifiedData => {
     *        updateData();
     *      })
     * ```
     */
    getRealtimeEvent(target: string): Subject<IEvent>;
    /**
     * 対象のオブジェクトを監視し、マネージドオブジェクトのリアルタイム通知を受け取ります
     *
     * @param {string} target 監視対象オブジェクト deviceId or '*' (テナント内全てのデバイスが対象)
     *
     * @returns リアルタイム通知で受け取ったマネージドオブジェクト
     * @example
     * ```typescript
     *    thingsCloudDataSupplier.getRealtimeManagedObject('12345')
     *      .subscribe(notifiedData => {
                updateData();
     *      })
     * ```
     */
    getRealtimeManagedObject(target: string): Subject<IManagedObject>;
    /**
     * リアルタイム通知のチャネル監視を解除します
     */
    unsubscribeRealtime(): void;
    /**
     * 指定された object の配列に関し、各 object の階層を平坦化し 1 層に変換します。
     * 例： [{a: 1, b: {c: 5}}] ---> [{a: 1, b_c: 5}]
     * object 値に配列を含む場合、配列内の object は平坦化されないことに注意して下さい。
     * 例： [{a: 1, b: [{c: 5}]}] ---> [{a: 1, b: [{c: 5}]}] (変更なし)
     *
     * @param objectArray object の配列
     * @returns  各要素が平坦化(つなぎ文字は _)された object の配列(Plot で利用可能な形式)
     * @example
     * ```typescript
     * :
     * // thingsCloudDataSupplier にインスタンスを格納
     * :
     * const array = [{a: 1, b: {c: 5}}];
     * const result = thingsCloudDataSupplier.flatten(array);
     * console.log(result); // expected: [{a: 1, b_c: 5}]
     * ```
     */
    private flatten;
    /**
     * flatten の実処理を行います。parent のデータが平坦化され、上書きされます。
     *
     * @param parent flatten 先のデータを格納する object
     * @param parentKey 階層化されたキー情報を連結したもの
     * @param obj flatten 対象となる object (再帰により子オブジェクトが指定される)
     * @example
     * ```typescript
     * :
     * // thingsCloudDataSupplier にインスタンスを格納
     * :
     * const obj = {a: 1, b: {c: 5}};
     * const result = thingsCloudDataSupplier._flatten(obj, '', obj);
     * console.log(result); // expected: {a: 1, b_c: 5}
     * ```
     */
    private flattenImpl;
}
